@@ -1,29 +1,28 @@
 # -*- coding: utf-8 -*-
-"""Constants for this package."""
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-from .. import tools
+"""REST API route definitions."""
+from ..tools import join_url
 
 
-class Router(object):
+class Router:
     """Simple object store for REST API routes."""
 
     def __init__(self, object_type, base, version, **routes):
-        """Constructor.
+        """Object store for REST API routes.
 
         Args:
-            object_type (:obj:`str`):
-                Object type.
-
+            object_type (:obj:`str`): object type for this set of routes
+            base (:obj:`str`): base path for this set of routes
+            version (:obj:`int`): api version for this set of routes
+            **routes: routes for this object_type
         """
         self._version = version
         self._base = base
         self._object_type = object_type
-        self.root = tools.join_url(base, object_type)
+        self.root = join_url(base, object_type)
         self._routes = ["root"]
         for k, v in routes.items():
             self._routes.append(k)
-            setattr(self, k, tools.join_url(self.root, v))
+            setattr(self, k, join_url(self.root, v))
 
     def __str__(self):
         """Show object info.
@@ -46,7 +45,7 @@ class Router(object):
         return self.__str__()
 
 
-class ApiV1(object):
+class ApiV1:
     """Routes provided by the Axonius REST API version 1."""
 
     version = 1
@@ -57,8 +56,10 @@ class ApiV1(object):
         base=base,
         version=version,
         by_id="{id}",
+        cached="cached",
         count="count",
         views="views",
+        view_by_id="views/saved/{id}",
         labels="labels",
         fields="fields",
     )
@@ -66,10 +67,12 @@ class ApiV1(object):
     devices = Router(
         object_type="devices",
         base=base,
+        cached="cached",
         version=version,
         by_id="{id}",
         count="count",
         views="views",
+        view_by_id="views/saved/{id}",
         labels="labels",
         fields="fields",
     )
@@ -87,11 +90,44 @@ class ApiV1(object):
         object_type="adapters",
         base=base,
         version=version,
-        cnxs="{adapter_name}/clients",
-        cnxs_uuid="{adapter_name}/clients/{cnx_uuid}",
-        upload_file="{adapter_name}/{node_id}/upload_file",
+        cnxs="{adapter_name_raw}/clients",
+        cnxs_uuid="{adapter_name_raw}/clients/{cnx_uuid}",
+        file_upload="{adapter_name_raw}/{adapter_node_id}/upload_file",
+        # file_download="{name}/{node_id}/download_file",
+        config_set="{adapter_name_raw}/config/{adapter_config_name}",
+        config_get="{adapter_name_plugin}/config/{adapter_config_name}",
     )
 
     alerts = Router(object_type="alerts", base=base, version=version)
 
-    all_objects = [users, devices, actions, adapters, alerts]
+    system = Router(
+        object_type="system",
+        base=base,
+        version=version,
+        instances="instances",
+        meta_about="meta/about",
+        meta_historical_sizes="meta/historical_sizes",
+        settings_lifecycle="settings/lifecycle",
+        settings_gui="settings/gui",
+        settings_core="settings/core",
+        discover_lifecycle="discover/lifecycle",
+        discover_start="discover/start",
+        discover_stop="discover/stop",
+        roles_default="roles/default",
+        roles="roles",
+        users="users",
+        user="users/{uuid}",
+        user_role="users/{uuid}/access",
+    )
+
+    all_objects = [
+        users,
+        devices,
+        actions,
+        adapters,
+        alerts,
+        system,
+    ]
+
+
+API_VERSION = ApiV1
